@@ -1,17 +1,17 @@
 // File_Pcm - Info for PCM files
-// Copyright (C) 2007-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -162,7 +162,7 @@ int8u Pcm_M2TS_bits_per_sample[4]=
 File_Pcm::File_Pcm()
 {
     //Configuration
-    ParserName=_T("PCM");
+    ParserName=__T("PCM");
     #if MEDIAINFO_TRACE
         Trace_Layers_Update(8); //Stream
     #endif //MEDIAINFO_TRACE
@@ -191,67 +191,67 @@ void File_Pcm::Streams_Fill()
 
     //Filling
     Ztring Firm, Endianness, Sign, ITU, Resolution;
-         if (Codec==_T("EVOB"))             {Firm=_T("");       Endianness=_T("Big");    Sign=_T("Signed");}                        //PCM Signed 16 bits Big Endian, Interleavement is for 2 samples*2 channels L0-1/L0-0/R0-1/R0-0/L1-1/L1-0/R1-1/R1-0/L0-2/R0-2/L1-2/R1-2, http://wiki.multimedia.cx/index.php?title=PCM
-    else if (Codec==_T("VOB"))              {Firm=_T("");       Endianness=_T("Big");    Sign=_T("Signed");}                        //PCM Signed 16 bits Big Endian, Interleavement is for 2 samples*2 channels L0-1/L0-0/R0-1/R0-0/L1-1/L1-0/R1-1/R1-0/L0-2/R0-2/L1-2/R1-2, http://wiki.multimedia.cx/index.php?title=PCM
-    else if (Codec==_T("M2TS"))             {Firm=_T("");       Endianness=_T("Big");    Sign=_T("Signed");}                        //PCM Signed         Big Endian
-    else if (Codec==_T("A_PCM/INT/BIG"))    {Firm=_T("");       Endianness=_T("Big");}
-    else if (Codec==_T("A_PCM/INT/LITTLE")) {Firm=_T("");       Endianness=_T("Little");}
-    else if (Codec==_T("A_PCM/INT/FLOAT"))  {Firm=_T("");       Endianness=_T("Big");    Sign=_T("Float");}
-    else if (Codec==_T("fl32"))             {                   Endianness=_T("Big");    Sign=_T("Float");    Resolution=_T("32");}
-    else if (Codec==_T("fl64"))             {                   Endianness=_T("Big");    Sign=_T("Float");    Resolution=_T("64");}
-    else if (Codec==_T("in24"))             {                   Endianness=_T("Big");    Sign=_T("Unsigned"); Resolution=_T("24");}
-    else if (Codec==_T("in32"))             {                   Endianness=_T("Big");    Sign=_T("Unsigned"); Resolution=_T("32");}
-    else if (Codec==_T("lpcm"))             {                   Endianness=_T("Big");    Sign=_T("Unsigned");}
-    else if (Codec==_T("raw "))             {                   Endianness=_T("Little"); Sign=_T("Unsigned");}
-    else if (Codec==_T("twos"))             {                   Endianness=_T("Big");    Sign=_T("Signed");}
-    else if (Codec==_T("sowt"))             {                   Endianness=_T("Little"); Sign=_T("Signed");}
-    else if (Codec==_T("SWF ADPCM"))        {Firm=_T("SWF");}
-    else if (Codec==_T("1"))                {   if (BitDepth)
+         if (Codec==__T("EVOB"))             {Firm=__T("");       Endianness=__T("Big");    Sign=__T("Signed");}                        //PCM Signed 16 bits Big Endian, Interleavement is for 2 samples*2 channels L0-1/L0-0/R0-1/R0-0/L1-1/L1-0/R1-1/R1-0/L0-2/R0-2/L1-2/R1-2, http://wiki.multimedia.cx/index.php?title=PCM
+    else if (Codec==__T("VOB"))              {Firm=__T("");       Endianness=__T("Big");    Sign=__T("Signed");}                        //PCM Signed 16 bits Big Endian, Interleavement is for 2 samples*2 channels L0-1/L0-0/R0-1/R0-0/L1-1/L1-0/R1-1/R1-0/L0-2/R0-2/L1-2/R1-2, http://wiki.multimedia.cx/index.php?title=PCM
+    else if (Codec==__T("M2TS"))             {Firm=__T("");       Endianness=__T("Big");    Sign=__T("Signed");}                        //PCM Signed         Big Endian
+    else if (Codec==__T("A_PCM/INT/BIG"))    {Firm=__T("");       Endianness=__T("Big");}
+    else if (Codec==__T("A_PCM/INT/LITTLE")) {Firm=__T("");       Endianness=__T("Little");}
+    else if (Codec==__T("A_PCM/INT/FLOAT"))  {Firm=__T("");       Endianness=__T("Big");    Sign=__T("Float");}
+    else if (Codec==__T("fl32"))             {                   Endianness=__T("Big");    Sign=__T("Float");    Resolution=__T("32");}
+    else if (Codec==__T("fl64"))             {                   Endianness=__T("Big");    Sign=__T("Float");    Resolution=__T("64");}
+    else if (Codec==__T("in24"))             {                   Endianness=__T("Big");    Sign=__T("Unsigned"); Resolution=__T("24");}
+    else if (Codec==__T("in32"))             {                   Endianness=__T("Big");    Sign=__T("Unsigned"); Resolution=__T("32");}
+    else if (Codec==__T("lpcm"))             {                   Endianness=__T("Big");    Sign=__T("Unsigned");}
+    else if (Codec==__T("raw "))             {                   Endianness=__T("Little"); Sign=__T("Unsigned");}
+    else if (Codec==__T("twos"))             {                   Endianness=__T("Big");    Sign=__T("Signed");}
+    else if (Codec==__T("sowt"))             {                   Endianness=__T("Little"); Sign=__T("Signed");}
+    else if (Codec==__T("SWF ADPCM"))        {Firm=__T("SWF");}
+    else if (Codec==__T("1"))                {   if (BitDepth)
                                                 {
                                                     if (BitDepth>8)
-                                                    {           Endianness=_T("Little"); Sign=_T("Signed");}
+                                                    {           Endianness=__T("Little"); Sign=__T("Signed");}
                                                     else
-                                                    {                                    Sign=_T("Unsigned");}
+                                                    {                                    Sign=__T("Unsigned");}
                                                 }
                                             }
-    else if (Codec==_T("2"))                {Firm=_T("Microsoft");}
-    else if (Codec==_T("3"))                {                   Endianness=_T("Float");}
-    else if (Codec==_T("10"))               {Firm=_T("OKI");}
-    else if (Codec==_T("11"))               {Firm=_T("Intel");}
-    else if (Codec==_T("12"))               {Firm=_T("Mediaspace");}
-    else if (Codec==_T("13"))               {Firm=_T("Sierra");}
-    else if (Codec==_T("14"))               {Firm=_T("Antex");}
-    else if (Codec==_T("17"))               {Firm=_T("Dialogic");}
-    else if (Codec==_T("18"))               {Firm=_T("Mediavision");}
-    else if (Codec==_T("20"))               {Firm=_T("Yamaha");}
-    else if (Codec==_T("33"))               {Firm=_T("Antex");}
-    else if (Codec==_T("36"))               {Firm=_T("DSP Solution");}
-    else if (Codec==_T("38"))               {Firm=_T("Natural MicroSystems");}
-    else if (Codec==_T("39"))               {Firm=_T("Crystal Semiconductor");}
-    else if (Codec==_T("3B"))               {Firm=_T("Rockwell");}
-    else if (Codec==_T("40"))               {Firm=_T("Antex Electronics");}
-    else if (Codec==_T("42"))               {Firm=_T("IBM");}
-    else if (Codec==_T("45"))               {Firm=_T("Microsoft"); ITU=_T("G.726");}
-    else if (Codec==_T("64"))               {Firm=_T("Apicom"); ITU=_T("G.726");}
-    else if (Codec==_T("65"))               {Firm=_T("Apicom"); ITU=_T("G.722");}
-    else if (Codec==_T("85"))               {Firm=_T("DataFusion Systems"); ITU=_T("G.726");}
-    else if (Codec==_T("8B"))               {Firm=_T("Infocom"); ITU=_T("G.721");}
-    else if (Codec==_T("97"))               {Firm=_T("ZyXEL");}
-    else if (Codec==_T("100"))              {Firm=_T("Rhetorex");}
-    else if (Codec==_T("125"))              {Firm=_T("Sanyo");}
-    else if (Codec==_T("140"))              {Firm=_T("Dictaphone"); ITU=_T("G.726");}
-    else if (Codec==_T("170"))              {Firm=_T("Unisys");}
-    else if (Codec==_T("175"))              {Firm=_T("SyCom"); ITU=_T("G.726");}
-    else if (Codec==_T("178"))              {Firm=_T("Knownledge");}
-    else if (Codec==_T("200"))              {Firm=_T("Creative");}
-    else if (Codec==_T("210"))              {Firm=_T("Uher");}
-    else if (Codec==_T("285"))              {Firm=_T("Norcom Voice Systems");}
-    else if (Codec==_T("1001"))             {Firm=_T("Olivetti");}
-    else if (Codec==_T("1C03"))             {Firm=_T("Lucent"); ITU=_T("G.723");}
-    else if (Codec==_T("1C0C"))             {Firm=_T("Lucent"); ITU=_T("G.723");}
-    else if (Codec==_T("4243"))             {ITU=_T("G.726");}
-    else if (Codec==_T("A105"))             {ITU=_T("G.726");}
-    else if (Codec==_T("A107"))             {ITU=_T("G.726");}
+    else if (Codec==__T("2"))                {Firm=__T("Microsoft");}
+    else if (Codec==__T("3"))                {                   Endianness=__T("Float");}
+    else if (Codec==__T("10"))               {Firm=__T("OKI");}
+    else if (Codec==__T("11"))               {Firm=__T("Intel");}
+    else if (Codec==__T("12"))               {Firm=__T("Mediaspace");}
+    else if (Codec==__T("13"))               {Firm=__T("Sierra");}
+    else if (Codec==__T("14"))               {Firm=__T("Antex");}
+    else if (Codec==__T("17"))               {Firm=__T("Dialogic");}
+    else if (Codec==__T("18"))               {Firm=__T("Mediavision");}
+    else if (Codec==__T("20"))               {Firm=__T("Yamaha");}
+    else if (Codec==__T("33"))               {Firm=__T("Antex");}
+    else if (Codec==__T("36"))               {Firm=__T("DSP Solution");}
+    else if (Codec==__T("38"))               {Firm=__T("Natural MicroSystems");}
+    else if (Codec==__T("39"))               {Firm=__T("Crystal Semiconductor");}
+    else if (Codec==__T("3B"))               {Firm=__T("Rockwell");}
+    else if (Codec==__T("40"))               {Firm=__T("Antex Electronics");}
+    else if (Codec==__T("42"))               {Firm=__T("IBM");}
+    else if (Codec==__T("45"))               {Firm=__T("Microsoft"); ITU=__T("G.726");}
+    else if (Codec==__T("64"))               {Firm=__T("Apicom"); ITU=__T("G.726");}
+    else if (Codec==__T("65"))               {Firm=__T("Apicom"); ITU=__T("G.722");}
+    else if (Codec==__T("85"))               {Firm=__T("DataFusion Systems"); ITU=__T("G.726");}
+    else if (Codec==__T("8B"))               {Firm=__T("Infocom"); ITU=__T("G.721");}
+    else if (Codec==__T("97"))               {Firm=__T("ZyXEL");}
+    else if (Codec==__T("100"))              {Firm=__T("Rhetorex");}
+    else if (Codec==__T("125"))              {Firm=__T("Sanyo");}
+    else if (Codec==__T("140"))              {Firm=__T("Dictaphone"); ITU=__T("G.726");}
+    else if (Codec==__T("170"))              {Firm=__T("Unisys");}
+    else if (Codec==__T("175"))              {Firm=__T("SyCom"); ITU=__T("G.726");}
+    else if (Codec==__T("178"))              {Firm=__T("Knownledge");}
+    else if (Codec==__T("200"))              {Firm=__T("Creative");}
+    else if (Codec==__T("210"))              {Firm=__T("Uher");}
+    else if (Codec==__T("285"))              {Firm=__T("Norcom Voice Systems");}
+    else if (Codec==__T("1001"))             {Firm=__T("Olivetti");}
+    else if (Codec==__T("1C03"))             {Firm=__T("Lucent"); ITU=__T("G.723");}
+    else if (Codec==__T("1C0C"))             {Firm=__T("Lucent"); ITU=__T("G.723");}
+    else if (Codec==__T("4243"))             {ITU=__T("G.726");}
+    else if (Codec==__T("A105"))             {ITU=__T("G.726");}
+    else if (Codec==__T("A107"))             {ITU=__T("G.726");}
 
     Fill(Stream_Audio, 0, Audio_Codec_String, "PCM");
     Fill(Stream_Audio, 0, Audio_Codec_Family, "PCM");
@@ -325,9 +325,9 @@ void File_Pcm::Data_Parse()
     Accept();
 
     //Parsing
-    if (Codec==_T("VOB") || Codec==_T("EVOB"))
+    if (Codec==__T("VOB") || Codec==__T("EVOB"))
         VOB();
-    else if (Codec==_T("M2TS"))
+    else if (Codec==__T("M2TS"))
         M2TS();
     else
     {
@@ -377,7 +377,7 @@ void File_Pcm::VOB()
                 size_t Buffer_Pos=Buffer_Offset+(size_t)Element_Offset;
 
                 std::memcpy(Info+Info_Offset, Buffer+Buffer_Pos, 4*(NumberOfChannelsMinusOne+1));
-                                
+
                 Info_Offset+=4*(NumberOfChannelsMinusOne+1);
                 Element_Offset+=5*(NumberOfChannelsMinusOne+1);
             }
