@@ -1,17 +1,17 @@
 // MediaInfoList_Internal - A list of MediaInfo
-// Copyright (C) 2002-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -57,14 +57,14 @@ MediaInfoList_Internal::MediaInfoList_Internal(size_t Count_Init)
 : Thread()
 {
     CriticalSectionLocker CSL(CS);
-    
+
     //Initialisation
     Info.reserve(Count_Init);
     for (size_t Pos=0; Pos<Info.size(); Pos++)
         Info[Pos]=NULL;
     ToParse_AlreadyDone=0;
     ToParse_Total=0;
-    
+
     //Threading
     BlockMethod=0;
     State=0;
@@ -94,7 +94,7 @@ size_t MediaInfoList_Internal::Open(const String &File_Name, const fileoptions_t
 
     //Get all filenames
     ZtringList List;
-    size_t Pos=File_Name.find(_T(':'));
+    size_t Pos=File_Name.find(__T(':'));
     if (Pos!=string::npos && Pos!=1)
         List.push_back(File_Name);
     else if (File::Exists(File_Name))
@@ -152,7 +152,7 @@ void MediaInfoList_Internal::Entry()
             for (std::map<String, String>::iterator Config_MediaInfo_Item=Config_MediaInfo_Items.begin(); Config_MediaInfo_Item!=Config_MediaInfo_Items.end(); Config_MediaInfo_Item++)
                 MI->Option(Config_MediaInfo_Item->first, Config_MediaInfo_Item->second);
             if (BlockMethod==1)
-                MI->Option(_T("Thread"), _T("1"));
+                MI->Option(__T("Thread"), __T("1"));
             MI->Open(ToParse.front());
             if (BlockMethod==1)
             {
@@ -259,7 +259,7 @@ void MediaInfoList_Internal::Close(size_t FilePos)
         delete Info[FilePos]; Info[FilePos]=NULL;
         Info.erase(Info.begin()+FilePos);
     }
-    
+
     ToParse_AlreadyDone=0;
     ToParse_Total=0;
 }
@@ -275,11 +275,11 @@ String MediaInfoList_Internal::Inform(size_t FilePos, size_t)
     {
         Ztring Retour;
         FilePos=0;
-        ZtringListList MediaInfo_Custom_View; MediaInfo_Custom_View.Write(Option(_T("Inform_Get")));
+        ZtringListList MediaInfo_Custom_View; MediaInfo_Custom_View.Write(Option(__T("Inform_Get")));
         bool XML=false;
-        if (MediaInfoLib::Config.Inform_Get()==_T("XML"))
+        if (MediaInfoLib::Config.Inform_Get()==__T("XML"))
             XML=true;
-        if (XML) Retour+=_T("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")+MediaInfoLib::Config.LineSeparator_Get()+_T("<Mediainfo version=\"")+MediaInfoLib::Config.Info_Version_Get().SubString(_T(" v"), Ztring())+_T("\">")+MediaInfoLib::Config.LineSeparator_Get();
+        if (XML) Retour+=__T("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")+MediaInfoLib::Config.LineSeparator_Get()+__T("<Mediainfo version=\"")+MediaInfoLib::Config.Info_Version_Get().SubString(__T(" v"), Ztring())+__T("\">")+MediaInfoLib::Config.LineSeparator_Get();
         else
         Retour+=MediaInfo_Custom_View("Page_Begin");
         while (FilePos<Info.size())
@@ -291,7 +291,7 @@ String MediaInfoList_Internal::Inform(size_t FilePos, size_t)
             }
             FilePos++;
         }
-        if (XML) Retour+=_T("</Mediainfo>")+MediaInfoLib::Config.LineSeparator_Get();
+        if (XML) Retour+=__T("</Mediainfo>")+MediaInfoLib::Config.LineSeparator_Get();
         else Retour+=MediaInfo_Custom_View("Page_End");//
         return Retour.c_str();
     }
@@ -383,33 +383,33 @@ String MediaInfoList_Internal::Option (const String &Option, const String &Value
 {
     CriticalSectionLocker CSL(CS);
     Ztring OptionLower=Option; OptionLower.MakeLowerCase();
-         if (Option==_T(""))
-        return _T("");
-    else if (OptionLower==_T("manguage_update"))
+         if (Option==__T(""))
+        return __T("");
+    else if (OptionLower==__T("manguage_update"))
     {
         //Special case : Language_Update must update all MediaInfo classes
         for (unsigned int Pos=0; Pos<Info.size(); Pos++)
             if (Info[Pos])
-                Info[Pos]->Option(_T("language_update"), Value);
+                Info[Pos]->Option(__T("language_update"), Value);
 
-        return _T("");
+        return __T("");
     }
-    else if (OptionLower==_T("create_dummy"))
+    else if (OptionLower==__T("create_dummy"))
     {
         Info.resize(Info.size()+1);
         Info[Info.size()-1]=new MediaInfo_Internal();
         Info[Info.size()-1]->Option(Option, Value);
-        return _T("");
+        return __T("");
     }
-    else if (OptionLower==_T("thread"))
+    else if (OptionLower==__T("thread"))
     {
         BlockMethod=1;
-        return _T("");
+        return __T("");
     }
-    else if (OptionLower.find(_T("file_"))==0)
+    else if (OptionLower.find(__T("file_"))==0)
     {
         Config_MediaInfo_Items[Option]=Value;
-        return _T("");
+        return __T("");
     }
     else
         return MediaInfo::Option_Static(Option, Value);
