@@ -1,17 +1,17 @@
 // File_Flv - Info for Flash files
-// Copyright (C) 2005-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -424,7 +424,7 @@ File_Flv::File_Flv()
 :File__Analyze()
 {
     //Configuration
-    ParserName=_T("FLV");
+    ParserName=__T("FLV");
     #if MEDIAINFO_EVENTS
         ParserIDs[0]=MediaInfo_Parser_Flv;
         StreamIDs_Width[0]=2;
@@ -495,9 +495,9 @@ void File_Flv::Streams_Fill()
         Merge(*Stream[Stream_Audio].Parser, Stream_Audio, 0, 0);
 
         //Special case: AAC
-        if (Retrieve(Stream_Audio, 0, Audio_Format)==_T("AAC")
-         || Retrieve(Stream_Audio, 0, Audio_Format)==_T("MPEG Audio")
-         || Retrieve(Stream_Audio, 0, Audio_Format)==_T("Vorbis"))
+        if (Retrieve(Stream_Audio, 0, Audio_Format)==__T("AAC")
+         || Retrieve(Stream_Audio, 0, Audio_Format)==__T("MPEG Audio")
+         || Retrieve(Stream_Audio, 0, Audio_Format)==__T("Vorbis"))
             Clear(Stream_Audio, 0, Audio_BitDepth); //Resolution is not valid for AAC / MPEG Audio / Vorbis
     }
 
@@ -729,7 +729,7 @@ void File_Flv::Header_Parse()
     {
         int32u Timestamp_Base;
         int8u  Timestamp_Extended;
-        Get_B1 (Type,                                           "Type"); //Param_Info1(Type<19?Flv_Type[Type]:_T("Unknown"));
+        Get_B1 (Type,                                           "Type"); //Param_Info1(Type<19?Flv_Type[Type]:__T("Unknown"));
         Get_B3 (BodyLength,                                     "BodyLength");
         Get_B3 (Timestamp_Base,                                 "Timestamp_Base"); //in ms
         Get_B1 (Timestamp_Extended,                             "Timestamp_Extended"); //TimeStamp = Timestamp_Extended*0x01000000+Timestamp_Base
@@ -1011,8 +1011,8 @@ void File_Flv::video_VP6(bool WithAlpha)
             Skip_B2(                                            "Offset");
         Skip_B1(                                                "MacroBlock_Height");
         Skip_B1(                                                "MacroBlock_Width");
-        Get_B1 (Height,                                         "Height"); Param_Info1(Ztring::ToZtring(Height*16)+_T(" pixels"));
-        Get_B1 (Width,                                          "Width"); Param_Info1(Ztring::ToZtring(Width*16)+_T(" pixels"));
+        Get_B1 (Height,                                         "Height"); Param_Info1(Ztring::ToZtring(Height*16)+__T(" pixels"));
+        Get_B1 (Width,                                          "Width"); Param_Info1(Ztring::ToZtring(Width*16)+__T(" pixels"));
 
         FILLING_BEGIN();
             if (Width && Height)
@@ -1065,7 +1065,7 @@ void File_Flv::video_AVC()
                     Open_Buffer_Continue(Stream[Stream_Video].Parser);
 
                     //Disabling this stream
-                    if (Stream[Stream_Video].Parser->File_GoTo!=(int64u)-1 || Stream[Stream_Video].Parser->Count_Get(Stream_Video)>0)
+                    if (Stream[Stream_Video].Parser->File_GoTo!=(int64u)-1 || Stream[Stream_Video].Parser->Count_Get(Stream_Video)>0 || (Config_ParseSpeed<1.0 && Stream[Stream_Video].PacketCount>=300))
                          video_stream_Count=false;
                 #else
                     Skip_XX(Element_Size-Element_Offset,        "AVC Data");
@@ -1101,9 +1101,9 @@ void File_Flv::audio()
     Element_Begin1("Stream header");
     BS_Begin();
     Get_S1 (4, codec,                                           "codec"); Param_Info1(Flv_Codec_Audio[codec]); Element_Info1(Flv_Codec_Audio[codec]);
-    Get_S1 (2, sampling_rate,                                   "sampling_rate"); Param_Info1(Ztring::ToZtring(Flv_SamplingRate[sampling_rate])+_T(" Hz"));
-    Get_SB (   is_16bit,                                        "is_16bit"); Param_Info1(Ztring::ToZtring(Flv_Resolution[is_16bit])+_T(" bits"));
-    Get_SB (   is_stereo,                                       "is_stereo"); Param_Info1(Ztring::ToZtring(Flv_Channels[is_stereo])+_T(" channel(s)"));
+    Get_S1 (2, sampling_rate,                                   "sampling_rate"); Param_Info1(Ztring::ToZtring(Flv_SamplingRate[sampling_rate])+__T(" Hz"));
+    Get_SB (   is_16bit,                                        "is_16bit"); Param_Info1(Ztring::ToZtring(Flv_Resolution[is_16bit])+__T(" bits"));
+    Get_SB (   is_stereo,                                       "is_stereo"); Param_Info1(Ztring::ToZtring(Flv_Channels[is_stereo])+__T(" channel(s)"));
     BS_End();
     Element_End0();
 
@@ -1257,6 +1257,10 @@ void File_Flv::meta_SCRIPTDATAVARIABLE()
 //---------------------------------------------------------------------------
 void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
 {
+    std::string StringDataModified(StringData);
+    if (!StringDataModified.empty() && StringDataModified[0]==__T('_'))
+        StringDataModified.erase(StringDataModified.begin());
+
     //Parsing
     int8u Type;
     Get_B1 (Type,                                               "Type"); Param_Info1C((Type<0x12), Flv_TagType[Type]);
@@ -1271,36 +1275,37 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 std::string ToFill;
                 Ztring ValueS;
                 stream_t StreamKind=Stream_General;
-                     if (StringData=="width") {ToFill="Width"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="height") {ToFill="Height"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="duration") meta_duration=Value*1000;
-                else if (StringData=="audiodatarate") {ToFill="BitRate"; StreamKind=Stream_Audio; ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="framerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="videoframerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="filesize") {meta_filesize=(int64u)Value;}
-                else if (StringData=="audiosize") {ToFill="StreamSize"; StreamKind=Stream_Audio; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true;}
-                else if (StringData=="videosize") {ToFill="StreamSize"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="videodatarate") {ToFill="BitRate"; StreamKind=Stream_Video; ValueS.From_Number(Value*1000, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="videocodecid") {; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
-                else if (StringData=="audiodelay") {ToFill="Delay"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="audiosamplerate") {ToFill="SamplingRate"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
-                else if (StringData=="audiosamplesize") {ToFill="BitDepth"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
-                else if (StringData=="totalduration") {ToFill="Duration"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="totaldatarate") {ToFill="OverallBitRate"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
-                else if (StringData=="bytelength") {if (File_Size!=Value) MetaData_NotTrustable=true;}
-                else if (!(StringData=="datasize"
-                       || StringData=="lasttimestamp"
-                       || StringData=="lastkeyframetimestamp"
-                       || StringData=="lastkeyframelocation"
-                       || StringData=="canSeekToEnd"
-                       || StringData=="keyframes_times"
-                       || StringData=="keyframes_filepositions"
-                       || StringData=="aacaot"
-                       || StringData=="audiochannels"
-                       || StringData=="audiocodecid"
-                       || StringData=="avclevel"
-                       || StringData=="avcprofile"
-                       || StringData=="moovPosition")) {StreamKind=Stream_General; ToFill=StringData; ValueS.From_Number(Value);}
+                     if (StringDataModified=="width") {ToFill="Width"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="height") {ToFill="Height"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="duration") meta_duration=Value*1000;
+                else if (StringDataModified=="audiodatarate") {ToFill="BitRate"; StreamKind=Stream_Audio; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="framerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="videoframerate") {ToFill="FrameRate"; StreamKind=Stream_Video; ValueS.From_Number(Value, 3); video_stream_FrameRate_Detected=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="filesize") {meta_filesize=(int64u)Value;}
+                else if (StringDataModified=="audiosize") {ToFill="StreamSize"; StreamKind=Stream_Audio; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true;}
+                else if (StringDataModified=="videosize") {ToFill="StreamSize"; StreamKind=Stream_Video; ValueS.From_Number(Value, 0); if (Value>File_Size) MetaData_NotTrustable=true; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="videodatarate") {ToFill="BitRate"; StreamKind=Stream_Video; ValueS.From_Number(Value*1000, 0); video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="videocodecid") {; video_stream_Count=true;} //1 file with FrameRate tag and video stream but no video present tag
+                else if (StringDataModified=="audiodelay") {ToFill="Delay"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="audiosamplerate") {ToFill="SamplingRate"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
+                else if (StringDataModified=="audiosamplesize") {ToFill="BitDepth"; StreamKind=Stream_Audio; if (Value>0) ValueS.From_Number(Value, 0);}
+                else if (StringDataModified=="totalduration") {ToFill="Duration"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="totaldatarate") {ToFill="OverallBitRate"; StreamKind=Stream_General; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="totalframes") {ToFill="FrameCount"; StreamKind=Stream_Video; ValueS.From_Number(Value*1000, 0);}
+                else if (StringDataModified=="bytelength") {if (File_Size!=Value) MetaData_NotTrustable=true;}
+                else if (!(StringDataModified=="datasize"
+                       || StringDataModified=="lasttimestamp"
+                       || StringDataModified=="lastkeyframetimestamp"
+                       || StringDataModified=="lastkeyframelocation"
+                       || StringDataModified=="canSeekToEnd"
+                       || StringDataModified=="keyframes_times"
+                       || StringDataModified=="keyframes_filepositions"
+                       || StringDataModified=="aacaot"
+                       || StringDataModified=="audiochannels"
+                       || StringDataModified=="audiocodecid"
+                       || StringDataModified=="avclevel"
+                       || StringDataModified=="avcprofile"
+                       || StringDataModified=="moovPosition")) {StreamKind=Stream_General; ToFill=StringData; ValueS.From_Number(Value);}
                 #if MEDIAINFO_TRACE
                     if (ValueS.empty())
                         ValueS.From_Number(Value, 0);
@@ -1308,9 +1313,9 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 #endif //MEDIAINFO_TRACE
                 if (!ToFill.empty())
                 {
-                    Fill(StreamKind, 0, ToFill.c_str(), ValueS);
+                    Fill(StreamKind, 0, ToFill.c_str(), ValueS, true);
                     if (ToFill=="FrameRate")
-                        Fill(StreamKind, 0, "FrameRate_Mode", "CFR");
+                        Fill(StreamKind, 0, "FrameRate_Mode", "CFR", Unlimited, true, true);
                 }
             }
             break;
@@ -1319,19 +1324,19 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 int8u Value;
                 Get_B1 (Value,                                  "Value");
                 std::string ToFill;
-                     if (StringData=="haskeyframes") {}
-                else if (StringData=="hasKeyframes") {}
-                else if (StringData=="hasVideo") {}
-                else if (StringData=="stereo") {}
-                else if (StringData=="canSeekToEnd") {}
-                else if (StringData=="hasAudio") {}
-                else if (StringData=="hasmetadata") {}
-                else if (StringData=="hasMetadata") {}
-                else if (StringData=="hasCuePoints") {}
-                else if (StringData=="canseekontime") {}
+                     if (StringDataModified=="haskeyframes") {}
+                else if (StringDataModified=="hasKeyframes") {}
+                else if (StringDataModified=="hasVideo") {}
+                else if (StringDataModified=="stereo") {}
+                else if (StringDataModified=="canSeekToEnd") {}
+                else if (StringDataModified=="hasAudio") {}
+                else if (StringDataModified=="hasmetadata") {}
+                else if (StringDataModified=="hasMetadata") {}
+                else if (StringDataModified=="hasCuePoints") {}
+                else if (StringDataModified=="canseekontime") {}
                 else {ToFill=StringData;}
                 Element_Info1(Value);
-                Fill(Stream_General, 0, ToFill.c_str(), Value?"Yes":"No");
+                Fill(Stream_General, 0, ToFill.c_str(), Value?"Yes":"No", Unlimited, true, true);
             }
             break;
         case 0x02 : //SCRIPTDATASTRING
@@ -1344,26 +1349,29 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                     Get_UTF8(Value_Size, Value,                 "Value");
                     size_t ToFill=(size_t)-1;
                     std::string ToFillS;
-                         if (StringData=="creator") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="creationdate") {ToFill=General_Encoded_Date; Value.Date_From_String(Value.To_UTF8().c_str());}
-                    else if (StringData=="encoder") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="Encoded_With") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="Encoded_By") {ToFill=General_Encoded_Application;}
-                    else if (StringData=="metadatacreator") {ToFill=General_Tagged_Application;}
-                    else if (StringData=="sourcedata") {}
-                    else if (StringData=="audiocodecid") {}
-                    else if (StringData=="videocodecid") {}
-                    else
+                         if (StringDataModified=="creator") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="creationdate") {ToFill=General_Encoded_Date; Value.Date_From_String(Value.To_UTF8().c_str());}
+                    else if (StringDataModified=="encoder") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="Encoded_With") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="Encoded_By") {ToFill=General_Encoded_Application;}
+                    else if (StringDataModified=="metadatacreator") {ToFill=General_Tagged_Application;}
+                    else if (StringDataModified=="creation_time") {ToFill=General_Encoded_Date; Value.insert(0, __T("UTC "));}
+                    else if (StringDataModified=="sourcedata") {}
+                    else if (StringDataModified=="audiocodecid") {}
+                    else if (StringDataModified=="videocodecid") {}
+                    else if (!(StringDataModified=="major_brand"
+                            || StringDataModified=="minor_version"
+                            || StringDataModified=="compatible_brands"))
                         ToFillS=StringData;
-                    if (Value.find(_T('\r'))!=std::string::npos)
-                        Value.resize(Value.find(_T('\r')));
-                    if (Value.find(_T('\n'))!=std::string::npos)
-                        Value.resize(Value.find(_T('\n')));
+                    if (Value.find(__T('\r'))!=std::string::npos)
+                        Value.resize(Value.find(__T('\r')));
+                    if (Value.find(__T('\n'))!=std::string::npos)
+                        Value.resize(Value.find(__T('\n')));
                     Element_Info1(Value);
                     if (ToFill!=(size_t)-1)
-                        Fill(Stream_General, 0, ToFill, Value);
+                        Fill(Stream_General, 0, ToFill, Value, true);
                     else if (!ToFillS.empty())
-                        Fill(Stream_General, 0, StringData.c_str(), Value);
+                        Fill(Stream_General, 0, StringData.c_str(), Value, true);
                 }
             }
             break;
@@ -1396,9 +1404,9 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 {
                     Ztring Value;
                     Get_Local(Value_Size, Value,                "Value");
-                    if (Value==_T("unknown")) Value.clear();
+                    if (Value==__T("unknown")) Value.clear();
                     Element_Info1C((!Value.empty()), Value);
-                    Fill(Stream_General, 0, StringData.c_str(), Value);
+                    Fill(Stream_General, 0, StringData.c_str(), Value, true);
                 }
             }
             break;
@@ -1411,14 +1419,14 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                 int16u Value;
                 Get_B2 (Value,                                  "Value");
                 Element_Info1(Value);
-                Fill(Stream_General, 0, StringData.c_str(), Value);
+                Fill(Stream_General, 0, StringData.c_str(), Value, true);
             }
             break;
         case 0x08 : //SCRIPTDATAVARIABLE[ECMAArrayLength]
             {
                 int32u ECMAArrayLength;
                 Get_B4 (ECMAArrayLength,                        "ECMAArrayLength");
-                Element_Info1(Ztring::ToZtring(ECMAArrayLength)+_T(" elements"));
+                Element_Info1(Ztring::ToZtring(ECMAArrayLength)+__T(" elements"));
                 for (int32u Pos=0; Pos<ECMAArrayLength; Pos++)
                 {
                     meta_SCRIPTDATAVARIABLE();
@@ -1452,7 +1460,7 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                      if (StringData=="metadatadate") {ToFill="Tagged_Date";}
                 else {ToFill=StringData;}
                 Element_Info1(ValueS);
-                Fill(Stream_General, 0, ToFill.c_str(), ValueS);
+                Fill(Stream_General, 0, ToFill.c_str(), ValueS, true);
             }
             break;
         case 0x0C : //SCRIPTDATALONGSTRING
@@ -1472,7 +1480,7 @@ void File_Flv::meta_SCRIPTDATAVALUE(const std::string &StringData)
                     else {ToFill=StringData;}
                     Element_Info1(Value);
                     if (!ToFill.empty())
-                        Fill(Stream_General, 0, ToFill.c_str(), Value);
+                        Fill(Stream_General, 0, ToFill.c_str(), Value, true);
                 }
             }
             break;
