@@ -1,17 +1,17 @@
 // File_Ism - Info for ISM files
-// Copyright (C) 2010-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2010-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -157,7 +157,7 @@ bool File_Ism::FileHeader_Begin()
                                         if (string(Param->Value())=="param")
                                         {
                                             Attribute=Param->Attribute("name");
-                                            if (Attribute && Ztring().From_UTF8(Attribute)==_T("trackID"))
+                                            if (Attribute && Ztring().From_UTF8(Attribute)==__T("trackID"))
                                             {
                                                 Attribute=Param->Attribute("value");
                                                 if (Attribute)
