@@ -1,17 +1,17 @@
 // File_ApeTag - Info for ApeTag tagged files
-// Copyright (C) 2005-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -169,10 +169,10 @@ void File_ApeTag::Data_Parse()
     else if (Key=="COPYRIGHT")      Fill(Stream_General, 0, General_Copyright, Value);
     else if (Key=="DISK")
     {
-                                    if (Value.find(_T("/"))!=Error)
+                                    if (Value.find(__T("/"))!=Error)
                                     {
-                                        Fill(Stream_General, 0, General_Part_Position_Total, Value.SubString(_T("/"), _T("")));
-                                        Fill(Stream_General, 0, General_Part_Position, Value.SubString(_T(""), _T("/")));
+                                        Fill(Stream_General, 0, General_Part_Position_Total, Value.SubString(__T("/"), __T("")));
+                                        Fill(Stream_General, 0, General_Part_Position, Value.SubString(__T(""), __T("/")));
                                     }
                                     else
                                         Fill(Stream_General, 0, General_Track_Position, Value);
@@ -183,10 +183,10 @@ void File_ApeTag::Data_Parse()
     else if (Key=="TITLE")          Fill(Stream_General, 0, General_Title, Value);
     else if (Key=="TRACK")
     {
-                                    if (Value.find(_T("/"))!=Error)
+                                    if (Value.find(__T("/"))!=Error)
                                     {
-                                        Fill(Stream_General, 0, General_Track_Position_Total, Value.SubString(_T("/"), _T("")));
-                                        Fill(Stream_General, 0, General_Track_Position, Value.SubString(_T(""), _T("/")));
+                                        Fill(Stream_General, 0, General_Track_Position_Total, Value.SubString(__T("/"), __T("")));
+                                        Fill(Stream_General, 0, General_Track_Position, Value.SubString(__T(""), __T("/")));
                                     }
                                     else
                                         Fill(Stream_General, 0, General_Track_Position, Value);
