@@ -1,17 +1,17 @@
 // File_Cdp - Info for EIA-608 files
-// Copyright (C) 2009-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2009-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -85,7 +85,7 @@ float32 Cdp_cdp_frame_rate(int8u cdp_frame_rate)
         default : return (float32) 0.000;
     }
 }
-    
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -98,7 +98,7 @@ File_Cdp::File_Cdp()
     PTS_DTS_Needed=true;
 
     //Temp
-    ParserName=_T("CDP");
+    ParserName=__T("CDP");
     #if MEDIAINFO_EVENTS
         ParserIDs[0]=MediaInfo_Parser_Cdp;
         StreamIDs_Width[0]=1;
@@ -254,7 +254,7 @@ void File_Cdp::cdp_header()
     Get_B2 (   cdp_identifier,                                  "cdp_identifier");
     Skip_B1(                                                    "cdp_length");
     BS_Begin();
-    Get_S1 (4, cdp_frame_rate,                                  "cdp_frame_rate"); Param_Info1(Ztring::ToZtring(Cdp_cdp_frame_rate(cdp_frame_rate))+_T(" fps"));
+    Get_S1 (4, cdp_frame_rate,                                  "cdp_frame_rate"); Param_Info1(Ztring::ToZtring(Cdp_cdp_frame_rate(cdp_frame_rate))+__T(" fps"));
     Skip_S1(4,                                                  "Reserved");
     Skip_SB(                                                    "time_code_present");
     Skip_SB(                                                    "ccdata_present");
