@@ -1,17 +1,17 @@
 // File_AvsV - Info for AVS Video files
-// Copyright (C) 2006-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2006-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -75,7 +75,7 @@ Ztring AvsV_level(int8u level_id)
         case 0x40 : return "@6.0";
         case 0x42 : return "@6.2";
         default :
-            return _T('@')+Ztring::ToZtring(level_id);
+            return __T('@')+Ztring::ToZtring(level_id);
     }
 }
 
@@ -669,7 +669,7 @@ void File_AvsV::extension_start()
                 }
 
     }
-    
+
     //Not sure, but the 3 first official files have this
     if (Element_Size-Element_Offset)
     {
@@ -696,7 +696,7 @@ void File_AvsV::picture_start()
     //Name
     Element_Name("picture_start");
     Element_Info1(Ztring::ToZtring(Frame_Count));
-    Element_Info1C((Element_Code==0xB3), _T("I"));
+    Element_Info1C((Element_Code==0xB3), __T("I"));
 
     //Parsing
     int8u picture_coding_type=(int8u)-1;
